package project.batch;

import java.sql.Connection;
import java.sql.Timestamp;
import java.util.Map;

import common.db.dao.Dao;
import common.db.dao.Dao.JdbcWork;
import common.sql.SelectQuery;
import common.sql.Selector;
import core.config.Factory;
import core.util.DateUtil;

/**
 * SQLクエリ
 *
 * @author Tadashi Nakayama
 */
public abstract class JdbcQuery implements SelectQuery, JdbcWork {

	/** パラメタ */
	private Map<String, Object> param;
	/** DAO */
	private Dao dao;

	/** 処理ユーザID */
	private String uid;
	/** 処理日時 */
	private Timestamp dateTime;

	/** フェッチサイズ */
	private int fetchSize = 1000;

	/**
	 * ユーザID設定
	 *
	 * @param val ユーザID
	 */
	public void setUid(final String val) {
		this.uid = val;
	}

	/**
	 * ユーザID取得
	 *
	 * @return ユーザID
	 */
	protected String getUid() {
		return this.uid;
	}

	/**
	 * 処理日時設定
	 *
	 * @param val 処理日時
	 */
	public void setDateTime(final Timestamp val) {
		this.dateTime = DateUtil.copyOf(val);
	}

	/**
	 * 処理日時取得
	 *
	 * @return val 処理日時
	 */
	protected Timestamp getDateTime() {
		return DateUtil.copyOf(this.dateTime);
	}

	/**
	 * パラメタ設定
	 *
	 * @param val パラメタマップ
	 */
	public void setParam(final Map<String, Object> val) {
		this.param = val;
	}

	/**
	 * パラメタ取得
	 *
	 * @return パラメタマップ
	 */
	@Override
	public Map<String, Object> makeParam() {
		return this.param;
	}

	/**
	 * DAO取得
	 *
	 * @return DAO
	 */
	protected Dao getDao() {
		return this.dao;
	}

	/**
	 * フェッチサイズ設定
	 *
	 * @param val フェッチサイズ
	 */
	public void setFetchSize(final int val) {
		this.fetchSize = val;
	}

	/**
	 * @see common.db.dao.Dao.JdbcWork#execute(java.sql.Connection)
	 */
	@Override
	public void execute(final Connection conn) {
		final var sc = Factory.create(Selector.class);
		sc.setConnection(conn);
		sc.setFetchSize(this.fetchSize);
		sc.search(this);
	}

	/**
	 * 処理実行
	 *
	 * @param val DAO
	 */
	public void execute(final Dao val) {
		this.dao = val;
		this.dao.doWork(this);
	}
}
